/*ESP32 Decimal to Binary to Hexadecimal Converter
 * Anthony Garofalo January 29th, 2018
 * www.YouTube.com/c/ProtoG42
 * 
 * Video of converter demo: https://youtu.be/NtJ-09U4fTo

  You will need to download and install the libraries below, as well as the ESP32 arduino core from https://github.com/espressif/arduino-esp32

*/

#include <SPI.h>
#include "SSD1306.h"
#include "esp32-hal-spi.h"

int CSpin1 = 13; //Chip select pin for the ones' place digit
int CSpin2 = 32; //Chip select pin for the tens' place digit


SSD1306  display(0x3c, 4, 15);//For ESP32 that I used

//#define CONFIG_DISABLE_HAL_LOCKS 1 //increases speed between SPI transfers for ESP32

int ledPins[] = {0, 17, 5, 14, 27, 26, 25};  //least-significant to most-significant bit
#define nBits sizeof(ledPins)/sizeof(ledPins[0])    //number of bits

/*ESP32 SPI PINOUT
  MISO 19 - MOSI 23 - SLK 18 - CS 5
*/

int dlay = 800;//Starting delay between entire digits
int Delay = 200;//Starting delay between individual segments
int number = 0;//Current number that the display is displaying
int value = 0;//Counter for the ones' place digit
int PrevValue = 10;
int value2 = 0;//Counter for the tens' place digit
int PrevValue2 = 10;
int CommandByte = 0b00000000;

//SPI Commands for driving individual segments
unsigned int Seg1ON   = 0b0000000000000001;
unsigned int Seg1OFF  = 0b0000000000000010;
unsigned int Seg2ON   = 0b0000000000000100;
unsigned int Seg2OFF  = 0b0000000000001000;
unsigned int Seg3ON   = 0b0000000000010000;
unsigned int Seg3OFF  = 0b0000000000100000;
unsigned int Seg4ON   = 0b0000000001000000;
unsigned int Seg4OFF  = 0b0000000010000000;
unsigned int Seg5ON   = 0b0000000100000000;
unsigned int Seg5OFF  = 0b0000001000000000;
unsigned int Seg6ON   = 0b0000010000000000;
unsigned int Seg6OFF  = 0b0000100000000000;
unsigned int Seg7ON   = 0b0001000000000000;
unsigned int Seg7OFF  = 0b0010000000000000;
unsigned int ClearALL = 0b0000000000000000;

/* Number Segment Assignments
  0 - 1, 2, 3, 4, 5, 6
  1 -       3, 4
  2 -    2, 3,    5, 6, 7
  3 -    2, 3, 4,    6, 7
  4 - 1,    3, 4,       7
  5 - 1, 2,    4, 5,    7
  6 - 1, 2,    4, 5, 6, 7
  7 -    2, 3, 4
  8 - 1, 2, 3, 4, 5, 6, 7
  9 - 1, 2, 3, 4, 5,   ,7
*/

//void DecimalDigit(int number, int digit);


void setup() {
 
  //Serial.begin(115200);//baud rate for ESP32
  
  pinMode(16, OUTPUT);//OLED Reset pin. Needs to be high for the OLED to work. This varies from different ESP32 OLED modules.
   
  pinMode(CSpin1, OUTPUT);
  pinMode(CSpin2, OUTPUT);
  digitalWrite(CSpin1, HIGH);
  digitalWrite(CSpin2, HIGH);

  for (byte i = 0; i < nBits; i++) {
    pinMode(ledPins[i], OUTPUT);
    digitalWrite(ledPins[i], LOW);
  }


  SPI.begin();
  SPI.setClockDivider(SPI_CLOCK_DIV4);
  SPI.setDataMode(SPI_MODE1);//important for the NXP MC33996
  SPI.setBitOrder(MSBFIRST);////important for the NXP MC33996

  delay(10);
  digitalWrite(16, HIGH);
  delay(10);
  display.init();
  //display.flipScreenVertically();
  //display.setFont(ArialMT_Plain_24); //use this font as the font below is custom font. Font generator I used: http://oleddisplay.squix.ch/#/home add to oledDisplayFonts.h
  display.setFont(Nimbus_Mono_L_Regular_52);

  delay(500);

  for (byte i = 0; i < nBits; i++) {
    digitalWrite(ledPins[i], HIGH);
  }

  ClearDecimalDigit(8, 1, Delay);//any possible digits left
  ClearDecimalDigit(8, 2, Delay);
  Animation(0, 100);//rotating animation
  Animation(0, 50);
  Animation(0, 20);
  Animation(0, 10);
  Animation(0, 5);
  Animation(0, 0);
  DecimalDigit(value2, 2, Delay);
  DecimalDigit(value, 1, Delay);

}

//--------------------------------------------------------------------------------------------------
//Custom Functions: DecimalDigit, ClearDecimalDigit, Animation, BinaryLED
//--------------------------------------------------------------------------------------------------

void loop() {

  for (value = 0; value < 10;) {
    if (value > 0) {
      ClearDecimalDigit(PrevValue, 1, Delay);
      DecimalDigit(value, 1, Delay);
    }

    //Serial.println(number); //will display number as decimal format in serial monitor
    //Serial.println(number, HEX); //will display number as hexadecimal format in serial monitor
    //Serial.println(number, BIN); //will display number as binary format in serial monitor
    //Serial.println();

    display.clear();
    display.setColor(WHITE);
    display.setTextAlignment(TEXT_ALIGN_CENTER);
    //display.drawString(64, 0, String(number, DEC));
    display.drawString(64, 0, "0x" + String(number, HEX));
    //display.drawString(64, 40, BinStr);
    //display.setFont(ArialMT_Plain_24);
    display.setFont(Nimbus_Mono_L_Regular_52);//cutom font
    display.display();

    BinaryLED(number);//Custom function to display binary number with the LEDs


    PrevValue = value;
    value++;
    number++;
    
    if (value < 10) {//avoid delay for  transition from 9 to 10, etc.
      delay(dlay);
    }
    
    //speed ramp up
    if (dlay > 0) {
      dlay = dlay - 50;
    }
    if (Delay > 0) {
      Delay = Delay - 10;
    }
    
  }
  if (number < 99) {
    ClearDecimalDigit(9, 1, Delay);
    DecimalDigit(0, 1, Delay);
  }

  PrevValue2 = value2;
  value2++;


  if (number > 99) {
    display.clear();
    display.display();
    number = 0;
    PrevValue2 = 9;
    value2 = 0;
    delay(500);

    ClearDecimalDigit(8, 1, Delay);
    ClearDecimalDigit(8, 2, Delay);
    Animation(0, 100);
    Animation(0, 50);
    Animation(0, 20);
    Animation(0, 10);
    Animation(0, 5);
    Animation(0, 0);
    DecimalDigit(8, 1, 50);
    DecimalDigit(8, 2, 50);

    for (byte i = 0; i < nBits; i++) {
      digitalWrite(ledPins[i], HIGH);
    }
    
    while (true) {//infinite loop until reset
    }
  }//end of if


  ClearDecimalDigit(PrevValue2, 2, Delay);
  DecimalDigit(value2, 2, Delay);


  if (value2 > 9) {
    value2 = 0;
  }


}//end of main

//--------------------------------------------------------------------------------------------------
//Custom Functions: BinaryLED, DecimalDigit, ClearDecimalDigit, Animation
//--------------------------------------------------------------------------------------------------

void BinaryLED(int n) {

  for (byte i = 0; i < nBits; i++) {
    digitalWrite(ledPins[i], n & 1);
    n /= 2;
  }
}

void DecimalDigit(int number, int digit, int Delay) {

  int CS;
  int SegmentDelay = 20;
  //int Delay = 100;
  if (digit == 1) {
    CS = 13;
  }
  else {
    CS = 32;
  }

  switch (number) {
    case 0:

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg6ON); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(Delay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg1ON); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(Delay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg2ON); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(Delay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg3ON); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(Delay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg4ON); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(Delay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg5ON); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(Delay);


      break;
    case 1:
      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg3ON); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(Delay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg4ON); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(Delay);

      break;
    case 2:

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg2ON); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(Delay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg3ON); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(Delay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg7ON); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(Delay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg6ON); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(Delay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg5ON); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(Delay);

      break;
    case 3:

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg2ON); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(Delay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg3ON); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(Delay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg7ON); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(Delay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg4ON); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(Delay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg5ON); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(Delay);

      break;
    case 4:

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg3ON); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(Delay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg4ON); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(Delay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg7ON); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(Delay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg1ON); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(Delay);

      break;

    case 5:

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg2ON); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(Delay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg1ON); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(Delay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg7ON); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(Delay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg4ON); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(Delay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg5ON); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(Delay);

      break;

    case 6 :
      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg2ON); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(Delay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg1ON); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(Delay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg6ON); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(Delay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg5ON); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(Delay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg4ON); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(Delay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg7ON); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(Delay);

      break;

    case 7:

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg2ON); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(Delay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg3ON); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(Delay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg4ON); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(Delay);

      break;

    case 8:
      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg2ON); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(Delay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg1ON); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(Delay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg7ON); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(Delay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg3ON); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(Delay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg6ON); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(Delay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg5ON); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(Delay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg4ON); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(Delay);


      break;

    case 9:
      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg2ON); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(Delay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg1ON); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(Delay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg7ON); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(Delay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg3ON); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(Delay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg4ON); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(Delay);

      break;

    default:
      break;
  }

}//end of DecimalDigit()

//--------------------------------------------------------------------------------------------------
//--------------------------------------------------------------------------------------------------

void ClearDecimalDigit(int number, int digit, int Delay) {

  int CS;
  int SegmentDelay = 20;
  //int Delay = 100;


  if (digit == 1) {
    CS = 13;
  }
  if (digit == 2) {
    CS = 32;
  }

  switch (number) {
    case 0:

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg6OFF); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(Delay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg1OFF); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);


      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(Delay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg2OFF); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(Delay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg3OFF); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(Delay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg4OFF); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(Delay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg5OFF); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(Delay);

      break;
    case 1:
      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg3OFF); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(Delay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg4OFF); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);


      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(Delay);

      break;
    case 2:

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg2OFF); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);


      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(Delay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg3OFF); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);


      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(Delay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg7OFF); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(Delay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg6OFF); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);


      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(Delay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg5OFF); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(Delay);
      break;
    case 3:

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg2OFF); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(Delay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg3OFF); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(Delay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg7OFF); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);
      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(Delay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg4OFF); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(Delay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg5OFF); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(Delay);

      //de-select slave
      delay(SegmentDelay);
      break;
    case 4:

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg3OFF); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(Delay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg4OFF); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(Delay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg7OFF); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(Delay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg1OFF); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(Delay);

      break;

    case 5:

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg2OFF); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(Delay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg1OFF); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(Delay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg7OFF); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(Delay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg4OFF); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(Delay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg5OFF); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(Delay);

      break;

    case 6 :
      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg2OFF); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(Delay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg1OFF); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(Delay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg6OFF); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(Delay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg5OFF); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(Delay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg4OFF); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(Delay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg7OFF); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(Delay);

      break;

    case 7:

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg2OFF); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(Delay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg3OFF); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(Delay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg4OFF); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(Delay);

      break;

    case 8:
      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg2OFF); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(Delay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg1OFF); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(Delay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg7OFF); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(Delay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg3OFF); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(Delay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg6OFF); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(Delay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg5OFF); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(Delay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg4OFF); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(Delay);

      break;

    case 9:
      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg2OFF); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(Delay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg1OFF); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(Delay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg7OFF); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(Delay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg3OFF); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(Delay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg4OFF); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(Delay);

      break;

    default:
      break;
  }
}//End of ClearDecimalDigit()

//--------------------------------------------------------------------------------------------------
//--------------------------------------------------------------------------------------------------


void Animation(int i, int Delay) {

  int CS;
  int SegmentDelay = 20;

  switch (i) {
    case 0:

      CS = 13;
      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg2ON); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);
      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      digitalWrite(ledPins[0], HIGH);
      delay(Delay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg3ON); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);
      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      digitalWrite(ledPins[0], LOW);
      digitalWrite(ledPins[1], HIGH);
      delay(Delay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg4ON); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);
      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      digitalWrite(ledPins[1], LOW);
      digitalWrite(ledPins[2], HIGH);
      delay(Delay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg5ON); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);
      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      digitalWrite(ledPins[2], LOW);
      digitalWrite(ledPins[3], HIGH);
      delay(Delay);

      CS = 32;

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg5ON); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);
      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      digitalWrite(ledPins[3], LOW);
      digitalWrite(ledPins[4], HIGH);
      delay(Delay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg6ON); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);
      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      digitalWrite(ledPins[4], LOW);
      digitalWrite(ledPins[5], HIGH);
      delay(Delay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg1ON); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);
      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      digitalWrite(ledPins[5], LOW);
      digitalWrite(ledPins[6], HIGH);
      delay(Delay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg2ON); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);
      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      digitalWrite(ledPins[6], LOW);
      digitalWrite(ledPins[7], HIGH);
      delay(Delay);

      CS = 13;

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg2OFF); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);
      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(Delay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg3OFF); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);
      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      digitalWrite(ledPins[7], LOW);
      digitalWrite(ledPins[6], HIGH);
      delay(Delay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg4OFF); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);
      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      digitalWrite(ledPins[6], LOW);
      digitalWrite(ledPins[5], HIGH);
      delay(Delay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg5OFF); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);
      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      digitalWrite(ledPins[5], LOW);
      digitalWrite(ledPins[4], HIGH);
      delay(Delay);

      CS = 32;

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg5OFF); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);
      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      digitalWrite(ledPins[4], LOW);
      digitalWrite(ledPins[3], HIGH);
      delay(Delay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg6OFF); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);
      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      digitalWrite(ledPins[3], LOW);
      digitalWrite(ledPins[2], HIGH);
      delay(Delay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg1OFF); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);
      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      digitalWrite(ledPins[2], LOW);
      digitalWrite(ledPins[1], HIGH);
      delay(Delay);

      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(Seg2OFF); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      delay(SegmentDelay);
      digitalWrite(CS, LOW); //select slave
      SPI.transfer(CommandByte);
      SPI.transfer16(ClearALL); //16 output bits
      digitalWrite(CS, HIGH); //de-select slave
      digitalWrite(ledPins[1], LOW);
      digitalWrite(ledPins[0], HIGH);
      delay(Delay);
      digitalWrite(ledPins[0], LOW);

      break;
  }

}




